<!--
This form is for bug reports ONLY!  
If you're looking for help check out the [readme](/README.md).
-->
**Bug report**

**What happened / Problem description**:

**What you expected to happen**:

**How to reproduce it (as minimally and precisely as possible)**:

**Anything else we need to know?**:

**Environment**:
- Dune version:
- DuMux version:  
- Others:
